@@ -452,6 +452,10 @@ class Base(Controller):
                 num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
                 get_drives(self.app.pargs.target, show_n=show_n, num_segments = num_segments)
 
+        if self.app.pargs.action == 'pull':
+            from ..ext.aws_s3 import pull_latest
+            pull_latest(self.app.pargs.target)
+
     @ex(
         help='Operations on the SSH config',
         arguments=[
