@@ -3,6 +3,13 @@ Operations to speed up S3 access.
 '''
 import pandas as pd
 
+def urlifier(dongle, drive_time):
+    """
+    Turns any dongle and drive time into a cabana url
+    """
+    url = f"http://cl-cabana.eba-eez4uaij.eu-west-1.elasticbeanstalk.com/cabana/?route={dongle}%7C{drive_time}"
+    return url
+
 
 def get_lastest_file(dongle_id: str):
     """
@@ -18,10 +25,10 @@ def get_lastest_file(dongle_id: str):
     last_segment, last_complete_drive = get_selected_drives(None, s3_resource, bucket_name, dongle_id, 10)
     # 064b1a99381ec054 2021-09-09--16-31-00 
     drive = '--'.join(last_segment.drive.split('--')[:-1])
-    ret = f"http://cl-cabana.eba-eez4uaij.eu-west-1.elasticbeanstalk.com/cabana/?route={last_segment.dongle_id}%7C{drive}"
-    return ret
+    return urlifier(last_segment.dongle_id, drive)
 
-def get_drives_df(s3_resource, bucket_name, dongle_id: str):
+
+def get_drives_df(s3_resource, bucket_name, dongle_id: str, filter=0):
     '''
     TODO: this probably requires a significant refactoring.
     '''
@@ -40,9 +47,14 @@ def get_drives_df(s3_resource, bucket_name, dongle_id: str):
     df['date'] = df.drive.str[:10]
     df['time'] = df.drive.str[12:20]
     df['seg_num'] = df.drive.str.split('--').str[-1]
+    df['drive_time'] = df.drive.str.split('--').str[:-1].str.join('--')
 
     df = df.sort_values(by=['date','time'], ascending=False)
     df.seg_num = pd.to_numeric(df.seg_num, errors='coerce')
+
+    df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
+
+    if filter: df = df[df.seg_num!=0]
     
     return df
 
@@ -58,7 +70,7 @@ def get_selected_drives(s3, s3_resource, bucket_name, dongle_id, show_n):
 
     return latest_drive, last_complete_drive
 
-def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int):
+def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int, latest=False):
     from tqdm import tqdm 
 
     raw_data_buckets = s3.list_objects_v2(Bucket='creationlabs-raw-data',Delimiter='/')
@@ -68,8 +80,9 @@ def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int)
 
     for did in tqdm(sorted(dongle_ids[:show_n])):
         latest_drive, last_complete_drive = get_selected_drives(s3, s3_resource, bucket_name, did, show_n)
-        latest_files.append(latest_drive)
-        latest_files.append(last_complete_drive)
+        # TODO: this does not feel like the last file
+        if latest:       latest_files.append(last_complete_drive)
+        else:  latest_files.append(latest_drive)
 
     df = pd.DataFrame(latest_files).reset_index()
     return df
@@ -88,6 +101,8 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
     s3_resource = boto3.resource('s3')
 
     if target=='-1':
+        df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n, latest=True)
+    elif target=='0':
         df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n)
     else:
         df = get_drives_df(s3_resource, bucket_name, dongle_id=target)
@@ -106,7 +121,7 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
 
     print(df.head(show_n))
 
-def download_latest(dongle_id):
+def pull_latest(dongle_id):
     """
     Download the latest file in the bucket.
     """
@@ -118,8 +133,8 @@ def download_latest(dongle_id):
     obj = s3.Object(bucket, dongle_id)
     files = obj.meta.client.list_objects(Bucket=bucket, Prefix=dongle_id)
     last_segment = '/'.join(files['Contents'][-1]['Key'].split('/')[:-1])
-    last_drive = '--'.join(last_segment.split('--')[:-1])
-    cmd = f'aws s3 sync s3://{bucket}/{dongle_id} .  --exclude="*" --include="{last_drive}*"'
+    last_drive = last_segment.split('--')[1]
     # s3.meta.client.download_file(bucket, last_drive, dongle_id)
+    cmd = f'aws s3 sync s3://{bucket}/{dongle_id} .  --exclude="*" --include="{last_drive}*"'
     print(f"Running {cmd}")
     os.system(cmd)
\ No newline at end of file
